@@ -161,6 +161,15 @@ class GPSString(object):
             raise self.FailedChecksum, ("Checksum: " + self.checksum())
 
 
+        ' If the string is already identified (self.id is set) go on, '
+        ' if not, then identify it. This prevents the user from having to '
+        ' identify it manually. '
+        try:
+            tmp = self.id
+        except:
+            self.identify()
+
+        ' Parse the code'
         if self.id == 1:
             'GGA'
             exp = '(?P<match>\$..GGA.*)\*(?P<chksum>..)'
